==> haskell-wai-handler-launch-3.0.3.1-751-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-handler-launch.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-handler-launch
version:              3.0.3.1
visibility:           public
id:                   wai-handler-launch-3.0.3.1-KFA26m1KhZfBF6uRgIe4CV
key:                  wai-handler-launch-3.0.3.1-KFA26m1KhZfBF6uRgIe4CV
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
synopsis:             Launch a web app in the default browser.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-handler-launch>.

category:             Web
abi:                  42683b0e6ad1771d0c2be74ca93bf569
exposed:              True
exposed-modules:      Network.Wai.Handler.Launch
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-handler-launch-3.0.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-handler-launch-3.0.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-handler-launch-3.0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-handler-launch
hs-libraries:         HSwai-handler-launch-3.0.3.1-KFA26m1KhZfBF6uRgIe4CV
depends:
    async-2.2.5-LqkzH7L8HyYHud0cQFVYjz base-4.17.2.1
    bytestring-0.11.5.3 http-types-0.12.4-ALPJWcgMeIc83stb9QW9Gl
    process-1.6.18.0 streaming-commons-0.2.3.0-GROQORqjjU1AlDKJpV35uv
    transformers-0.5.6.2 wai-3.2.4-1yop7BvplydTH1djBo1do
    warp-3.3.30-8OpZYlaRw56DjKQnzqAXnQ

haddock-interfaces:
    /usr/share/doc/haskell-wai-handler-launch/html/wai-handler-launch.haddock

haddock-html:         /usr/share/doc/haskell-wai-handler-launch/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-handler-launch-3.0.3.1-752-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-handler-launch.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-handler-launch
version:              3.0.3.1
visibility:           public
id:                   wai-handler-launch-3.0.3.1-A5ob2qor9ei9VKRmVDN5zO
key:                  wai-handler-launch-3.0.3.1-A5ob2qor9ei9VKRmVDN5zO
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
synopsis:             Launch a web app in the default browser.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-handler-launch>.

category:             Web
abi:                  78d1581ccac0c34fbbbc1acad3d3ec0b
exposed:              True
exposed-modules:      Network.Wai.Handler.Launch
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-handler-launch-3.0.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-handler-launch-3.0.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-handler-launch-3.0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-handler-launch
hs-libraries:         HSwai-handler-launch-3.0.3.1-A5ob2qor9ei9VKRmVDN5zO
depends:
    async-2.2.5-BcqMz9kSLpQJiwvDzQjiwa base-4.17.2.1
    bytestring-0.11.5.3 http-types-0.12.4-3tEQsAXlW3W83gTXUT3vtQ
    process-1.6.18.0 streaming-commons-0.2.3.0-IHlgvlVfulNLSLRP191V6d
    transformers-0.5.6.2 wai-3.2.4-FyKF4IGn0hJInObjv662sx
    warp-3.3.30-GBSaB1lG8zUDcaCcslac6i

haddock-interfaces:
    /usr/share/doc/haskell-wai-handler-launch/html/wai-handler-launch.haddock

haddock-html:         /usr/share/doc/haskell-wai-handler-launch/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
